## Introduction
This repository includes:

1. PyTorch model weights files for the V1, V2, and V3 models.
2. Test datasets from the annotated 2021 and 2024 data.
3. A python script (test_models.py) to test each model with the associated test datasets and produce the model accuracy figures presented in the report.

## Getting Started
All instructions assume the user is using a computer using Ubuntu Linux 20.04 or later with Python3.8 or later. Operation on other operating systems may require some modification to these instructions.

Models will run on your computer's CUDA-capable NVIDIA GPU if one is available. Otherwise, models will run on the CPU. Testing on the CPU may take longer but will not affect the accuracy of the models.

1. Install the required python modules using the requirements.txt file, preferably using a virtual environment on a Linux computer.

#   (optional) create and activate a virtual environment
    python3 -m venv .venv
    source .venv/bin/activate

#   install the requirements
    python3 -m pip install -r requirements.txt

#   (optional) Install CUDA
    Instructions for instaling CUDA for your particular operating system may be found here: https://developer.nvidia.com/cuda-12-6-2-download-archive

2. Run 'test_models.py' to load each model and test that model on the associated dataset. For example, the V1 model will be tested against the 2021 test data. The outputs of each script will be saved to ./runs/detect/ and will include confusion matrices, F1, P, PR, and R curves, and example images of the human annotations (labels) and the model predictions.

#   run the test script
    python3 test_models.py

## Data Format
Release data are saved in YOLO format, described in detail here: https://docs.ultralytics.com/datasets/detect/.

Model classes are:
- other
- smolt
- debris

## Liscense
These data, example code, and trained models are licensed under the 3-Clause BSD liscense.

Copyright 2024 MarineSitu Inc. 

Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.

3. Neither the name of the copyright holder nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS “AS IS” AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.